"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const chalk_1 = __importDefault(require("chalk"));
const gh_user_1 = __importDefault(require("gh-user"));
const yeoman_generator_1 = __importDefault(require("yeoman-generator"));
const yosay_1 = __importDefault(require("yosay"));
class Index extends yeoman_generator_1.default {
    constructor() {
        super(...arguments);
        this.packageName = 'generator-node-tsnext';
    }
    initializing() {
        try {
            const ghTask = this.user.github.username()
                .then((un) => Promise.all([un, gh_user_1.default(un)]))
                .then(([un, info]) => {
                return [un, info.html_url];
            })
                .catch(() => []);
            return ghTask.then(([username, homepage]) => {
                this.user.info = {
                    username,
                    homepage,
                    name: this.user.git.name(),
                    email: this.user.git.email(),
                };
            });
        }
        catch (_) {
            this.user.info = {
                name: this.user.git.name() || '',
                email: this.user.git.email() || '',
                username: '',
                homepage: '',
            };
        }
    }
    prompting() {
        this.log(yosay_1.default(`Welcome to the stunning ${chalk_1.default.red(this.packageName)}!`));
        const fallbackDescription = 'Simple Node.js module to output greeting message, written in TypeScript';
        const prompts = [
            {
                type: 'input',
                name: 'packageName',
                message: 'What would you like your project to be named?',
                default: () => {
                    return process.cwd().replace(/(?:.*[/\\])([^/\\]+?)[/\\]*?$/gi, '$1');
                },
            },
            {
                type: 'input',
                name: 'description',
                message: 'Description',
            },
            {
                type: 'input',
                name: 'homepage',
                message: 'Homepage URL',
            },
            {
                type: 'input',
                name: 'repoUrl',
                message: 'Link to the repository',
            },
            {
                type: 'input',
                name: 'authorName',
                message: 'Author\'s Name',
                default: this.user.info.name,
            },
            {
                type: 'input',
                name: 'authorEmail',
                message: 'Author\'s email',
                default: this.user.info.email,
            },
            {
                type: 'input',
                name: 'authorUrl',
                message: 'Author\'s homepage',
                default: this.user.info.homepage,
            },
            {
                type: 'input',
                name: 'gitName',
                message: 'Github username or organization',
                default: this.user.info.username,
            },
        ];
        return this.prompt(prompts).then((props) => {
            this.props = Object.assign({}, props, {
                docDescription: (props.description || fallbackDescription).replace(/typeScript/i, '[TypeScript][typescript-url]'),
                thisYear: new Date().getFullYear(),
            });
        });
    }
    writing() {
        const NON_TPLS = [
            'src/index.ts',
            'tsconfig.json',
            'tsconfig.prod.json',
            'tslint.json',
            'tslint.prod.json',
        ];
        const TPLS = [
            '_.editorconfig',
            '_.gitattributes',
            '_.gitignore',
            '_.npmrc',
            '_LICENSE',
            '_package.json',
            '_README.md',
        ];
        NON_TPLS.map((n) => {
            return this.fs.copy(this.templatePath(n), this.destinationPath(n), this.props);
        });
        TPLS.map((n) => {
            return this.fs.copyTpl(this.templatePath(n), this.destinationPath(n.replace(/(_)/gi, '')), this.props);
        });
    }
    install() {
        this.installDependencies({
            bower: false,
            npm: true,
        });
    }
}
exports.Index = Index;
exports.default = Index;
module.exports = Index;
//# sourceMappingURL=index.js.map